@@ -24,7 +24,7 @@
 //! doc](http://sass-lang.com/documentation/file.SASS_REFERENCE.html).
 //! This implementation is incomplete but getting there, if slowly.
 //!
-//! Progress: 3872 of 6477 tests passed in dart-sass compatibility mode.
+//! Progress: 4013 of 6478 tests passed in dart-sass compatibility mode.
 //!
 //! If you want a working rust library for sass right now, you may
 //! be better of with [sass-rs](https://crates.io/crates/sass-rs)
@@ -53,10 +53,10 @@ pub use crate::error::Error;
 pub use crate::file_context::{FileContext, FsFileContext};
 use crate::output::Format;
 pub use crate::parser::{
-    parse_scss_data, parse_scss_file, parse_scss_path, parse_value_data,
-    ParseError, SourceName, SourcePos,
+    parse_scss_data, parse_value_data, ParseError, SourceFile, SourceName,
+    SourcePos,
 };
-pub use crate::variablescope::{Scope, ScopeRef};
+pub use crate::variablescope::{Scope, ScopeError, ScopeRef};
 
 /// Parse a scss value from a buffer and write its css representation
 /// in the given format.
@@ -129,7 +129,7 @@ pub fn compile_scss_path(
     format: Format,
 ) -> Result<Vec<u8>, Error> {
     let file_context = FsFileContext::new();
-    let (sub_context, path) = file_context.file(path);
-    let items = parse_scss_path(&path)?;
-    format.write_root(&items, ScopeRef::new_global(format), &sub_context)
+    let source = file_context.file(path)?;
+    let items = source.parse()?;
+    format.write_root(&items, ScopeRef::new_global(format), &file_context)
 }
