@@ -1,5 +1,6 @@
 use super::Format;
 use crate::css::{BodyItem, CssString, Rule, Value};
+use crate::value::Quotes;
 use crate::{Error, ScopeRef};
 use std::cmp::Ordering;
 use std::collections::BTreeMap;
@@ -142,6 +143,19 @@ impl CssBuf {
                     if self.format.is_compressed() { "" } else { " " },
                     val.format(self.format).to_string().replace('\n', " "),
                 )?,
+                BodyItem::CustomProperty(ref name, ref val) => write!(
+                    self.buf,
+                    "{}:{}{};",
+                    name,
+                    if val.quotes() != Quotes::None
+                        && !self.format.is_compressed()
+                    {
+                        " "
+                    } else {
+                        ""
+                    },
+                    val,
+                )?,
                 BodyItem::Comment(ref c) => {
                     let indent = self.indent;
                     let existing = c
@@ -156,7 +170,7 @@ impl CssBuf {
                         Ordering::Greater => {
                             let start =
                                 self.format.get_indent(indent - existing);
-                            self.add_str(&c.replace("\n", start));
+                            self.add_str(&c.replace('\n', start));
                         }
                         Ordering::Less => {
                             let start =
