@@ -1,10 +1,16 @@
+//! This module provides `handle_body` (and internally `handle_item`),
+//! that does most of the work for [`super::Format::write_root`].
+
+// https://github.com/rust-lang/rust-clippy/issues/7846
+// https://users.rust-lang.org/t/using-an-option-mut-t-in-a-loop-clippy-complains/72481/2
+#![allow(clippy::needless_option_as_deref)]
+
 use super::cssbuf::{CssBuf, CssHead};
 use crate::css::{BodyItem, Rule, Selectors};
 use crate::error::Error;
 use crate::file_context::FileContext;
-use crate::parser::parse_imported_scss_file;
 use crate::sass::{
-    self, get_global_module, Expose, FormalArgs, Function, Item, Mixin, Name,
+    get_global_module, CallArgs, Expose, Function, Item, MixinDecl, Name,
     UseAs,
 };
 use crate::value::ValueRange;
@@ -53,11 +59,13 @@ fn handle_item(
                     ));
                 }
                 module
-            } else if let Some((sub_context, path, mut file)) =
-                file_context.find_file_use(name.value())?
-            {
+            } else if let Some(sourcefile) = file_context.find_file_use(
+                name.value(),
+                // TODO: Get a proper pos!
+                crate::parser::code_span(b"").into(),
+            )? {
                 head.load_module(
-                    &path,
+                    sourcefile.path(),
                     |head| {
                         let module = ScopeRef::new_global(format);
                         for (name, value, default) in with {
@@ -77,19 +85,14 @@ fn handle_item(
                                 ));
                             }
                         }
-                        let items = parse_imported_scss_file(
-                            &mut file,
-                            &path,
-                            // TODO: Get a proper pos!
-                            crate::parser::code_span(b"").into(),
-                        )?;
+                        let items = sourcefile.parse()?;
                         handle_body(
                             &items,
                             head,
                             None,
                             buf,
                             module.clone(),
-                            &sub_context,
+                            file_context,
                         )?;
                         Ok(module)
                     })?
@@ -108,11 +111,13 @@ fn handle_item(
                     ));
                 }
                 module
-            } else if let Some((sub_context, path, mut file)) =
-                file_context.find_file_use(name.value())?
-            {
+            } else if let Some(sourcefile) = file_context.find_file_use(
+                name.value(),
+                // TODO: Get a proper pos!
+                crate::parser::code_span(b"").into(),
+            )? {
                 head.load_module(
-                    &path,
+                    sourcefile.path(),
                     |head| {
                         let module = ScopeRef::new_global(format);
                         for (name, value, default) in with {
@@ -132,19 +137,14 @@ fn handle_item(
                                 ));
                             }
                         }
-                        let items = parse_imported_scss_file(
-                            &mut file,
-                            &path,
-                            // TODO: Get a proper pos!
-                            crate::parser::code_span(b"").into(),
-                        )?;
+                        let items = sourcefile.parse()?;
                         handle_body(
                             &items,
                             head,
                             None,
                             buf,
                             module.clone(),
-                            &sub_context,
+                            file_context,
                         )?;
                         Ok(module)
                     })?
@@ -158,14 +158,11 @@ fn handle_item(
             'name: for name in names {
                 if args.is_null() {
                     let x = name.evaluate(scope.clone())?;
-                    if let Some((sub_context, path, mut file)) =
-                        file_context.find_file_import(x.value())?
+                    if let Some(sourcefile) = file_context
+                        .find_file_import(x.value(), pos.clone())?
                     {
-                        let items = parse_imported_scss_file(
-                            &mut file,
-                            &path,
-                            pos.clone(),
-                        )?;
+                        scope.lock_loading(sourcefile.path(), pos.clone())?;
+                        let items = sourcefile.parse()?;
                         let mut thead = CssHead::new(format);
                         let module = ScopeRef::sub(scope.clone());
                         handle_body(
@@ -174,7 +171,7 @@ fn handle_item(
                             rule.as_deref_mut(),
                             buf,
                             module.clone(),
-                            &sub_context,
+                            file_context,
                         )?;
                         head.merge_imports(thead);
                         scope.do_use(
@@ -183,6 +180,7 @@ fn handle_item(
                             &UseAs::Star,
                             &Expose::All,
                         )?;
+                        scope.unlock_loading(sourcefile.path());
                         continue 'name;
                     }
                 }
@@ -299,47 +297,25 @@ fn handle_item(
         Item::MixinDeclaration(ref name, ref args, ref body, ref pos) => {
             scope.define_mixin(
                 name.into(),
-                Mixin {
-                    args: args.clone(),
-                    scope: scope.clone(),
-                    body: body.clone(),
-                    pos: pos.clone(),
-                },
+                MixinDecl::new(args, &scope, body, pos),
             )
         }
         Item::MixinCall(ref name, ref args, ref body, ref pos) => {
-            let sel = scope.get_selectors().clone();
             if let Some(mixin) = scope.get_mixin(&name.into()) {
-                let subscope = mixin
-                    .args
-                    .eval(
-                        ScopeRef::sub_selectors(mixin.scope.clone(), sel),
-                        args.evaluate(scope.clone())?,
-                    )
-                    .map_err(|e| match e {
-                        sass::ArgsError::Eval(e) => e,
-                        ae => Error::BadCall(
-                            ae.to_string(),
-                            pos.in_call(name),
-                            Some(mixin.pos.clone()),
-                        ),
-                    })?;
-                subscope.define_mixin(
-                    Name::from_static("%%BODY%%"),
-                    Mixin {
-                        args: FormalArgs::none(),
-                        scope,
-                        body: body.clone().unwrap_or_else(Mixin::no_body),
-                        // TODO: Get a better pos?
-                        pos: pos.clone(),
-                    },
-                );
+                let mixin = mixin.get(
+                    name,
+                    scope.clone(),
+                    args,
+                    pos,
+                    file_context,
+                )?;
+                mixin.define_content(&scope, body, pos);
                 handle_body(
                     &mixin.body,
                     head,
                     rule,
                     buf,
-                    subscope,
+                    mixin.scope,
                     file_context,
                 )
                 .map_err(|e: Error| match e {
@@ -364,19 +340,27 @@ fn handle_item(
                 ));
             }
         }
-        Item::Content => {
+        Item::Content(pos) => {
             if let Some(content) =
                 scope.get_mixin(&Name::from_static("%%BODY%%"))
             {
-                let sel = scope.get_selectors().clone();
-                handle_body(
-                    &content.body,
-                    head,
-                    rule,
-                    buf,
-                    ScopeRef::sub_selectors(content.scope, sel),
-                    file_context,
-                )?;
+                if !content.is_no_body() {
+                    let mixin = content.get(
+                        "@content",
+                        scope,
+                        &CallArgs::new(vec![])?,
+                        pos,
+                        file_context,
+                    )?;
+                    handle_body(
+                        &mixin.body,
+                        head,
+                        rule,
+                        buf,
+                        mixin.scope,
+                        file_context,
+                    )?;
+                }
             }
         }
 
@@ -485,6 +469,22 @@ fn handle_item(
                 return Err(Error::S("Global property not allowed".into()));
             }
         }
+        Item::CustomProperty(ref name, ref value) => {
+            if let Some(rule) = rule {
+                let v = value.evaluate(scope.clone())?;
+                if !v.is_null() {
+                    let name = name.evaluate(scope)?;
+                    rule.push(BodyItem::CustomProperty(
+                        name.value().into(),
+                        v,
+                    ));
+                }
+            } else {
+                return Err(Error::S(
+                    "Global custom property not allowed".into(),
+                ));
+            }
+        }
         Item::NamespaceRule(ref name, ref value, ref body) => {
             if let Some(rule) = rule {
                 let value = value.evaluate(scope.clone())?;
