@@ -8,6 +8,7 @@ macro_rules! check_parse {
 }
 
 pub(crate) mod css;
+mod css_function;
 mod error;
 pub mod formalargs;
 mod imports;
@@ -23,7 +24,9 @@ pub use pos::{SourceName, SourcePos};
 
 use self::formalargs::{call_args, formal_args};
 use self::selectors::selectors;
-use self::strings::{name, sass_string, sass_string_dq, sass_string_sq};
+use self::strings::{
+    custom_value, name, sass_string, sass_string_dq, sass_string_sq,
+};
 use self::util::{
     comment2, ignore_comments, ignore_space, opt_spacelike, semi_or_end,
     spacelike,
@@ -49,15 +52,47 @@ use nom::multi::{
 use nom::sequence::{delimited, pair, preceded, terminated};
 use nom::IResult;
 use nom_locate::LocatedSpan;
-use std::fs::File;
 use std::io::Read;
-use std::path::Path;
 use std::str::{from_utf8, Utf8Error};
 
 pub type Span<'a> = LocatedSpan<&'a [u8], &'a SourceName>;
 /// A Parsing Result; ok gives a span for the rest of the data and a parsed T.
 type PResult<'a, T> = IResult<Span<'a>, T>;
 
+/// The full data of a source file.
+///
+/// This type contains both the contents (as a `Vec<u8>`) of a file
+/// and information on from where (and why) it was loaded.
+/// You can create a SourceFile with the [`SourceFile::read`]
+/// constructor, but normally you will get one from a
+/// [`FileContext`][crate::FileContext].
+pub struct SourceFile {
+    data: Vec<u8>,
+    source: SourceName,
+}
+
+impl SourceFile {
+    /// Create a SourceFile from something readable and a name.
+    pub fn read<T: Read>(
+        file: &mut T,
+        source: SourceName,
+    ) -> Result<Self, Error> {
+        let mut data = vec![];
+        file.read_to_end(&mut data)
+            .map_err(|e| Error::Input(source.name().to_string(), e))?;
+        Ok(SourceFile { data, source })
+    }
+
+    /// Parse this scss source.
+    pub fn parse(&self) -> Result<Vec<Item>, Error> {
+        let data = Span::new_extra(&self.data, &self.source);
+        Ok(ParseError::check(sassfile(data))?)
+    }
+    pub(crate) fn path(&self) -> &str {
+        self.source.name()
+    }
+}
+
 pub fn code_span(value: &[u8]) -> Span {
     use lazy_static::lazy_static;
     lazy_static! {
@@ -95,49 +130,6 @@ fn test_parse_value_data_2() -> Result<(), Error> {
     Ok(())
 }
 
-/// Parse a scss file by path.
-///
-/// Returns a vec of the top level items of the file (or an error message).
-pub fn parse_scss_path(path: &Path) -> Result<Vec<Item>, Error> {
-    let source = SourceName::root(path.display());
-    let mut f = File::open(path)
-        .map_err(|e| Error::Input(source.name().to_string(), e))?;
-    do_parse_scss_file(&mut f, &source)
-}
-
-/// Parse a scss file.
-///
-/// Returns a vec of the top level items of the file (or an error message).
-///
-/// **Attention**: Previously, this function took a path to the file
-/// instead of a file itself. That function has been renamed to [`parse_scss_path()`].
-pub fn parse_scss_file<T: Read>(
-    file: &mut T,
-    path: &str,
-) -> Result<Vec<Item>, Error> {
-    do_parse_scss_file(file, &SourceName::root(path))
-}
-
-pub fn parse_imported_scss_file<T: Read>(
-    file: &mut T,
-    path: &str,
-    from: SourcePos,
-) -> Result<Vec<Item>, Error> {
-    let source = SourceName::imported(path, from);
-    do_parse_scss_file(file, &source)
-}
-
-fn do_parse_scss_file<T: Read>(
-    file: &mut T,
-    source: &SourceName,
-) -> Result<Vec<Item>, Error> {
-    let mut data = vec![];
-    file.read_to_end(&mut data)
-        .map_err(|e| Error::Input(source.name().to_string(), e))?;
-    let data = Span::new_extra(&data, source);
-    Ok(ParseError::check(sassfile(data))?)
-}
-
 /// Parse scss data from a buffer.
 ///
 /// Returns a vec of the top level items of the file (or an error message).
@@ -184,15 +176,29 @@ fn rule_start(input: Span) -> PResult<Selectors> {
 }
 
 fn body_item(input: Span) -> PResult<Item> {
-    let (input, tag) =
-        alt((tag("$"), tag("/*"), tag(";"), tag("@"), tag("")))(input)?;
+    let (rest, tag) =
+        alt((tag("$"), tag("/*"), tag(";"), tag("@"), tag("--"), tag("")))(
+            input,
+        )?;
     match *tag.fragment() {
-        b"$" => variable_declaration2(input),
-        b"/*" => comment_item(input),
-        b";" => Ok((input, Item::None)),
-        b"@" => at_rule2(input),
+        b"$" => variable_declaration2(rest),
+        b"/*" => comment_item(rest),
+        b";" => Ok((rest, Item::None)),
+        b"@" => at_rule2(rest),
+        b"--" => {
+            let result = custom_property(rest);
+            if result.is_err() {
+                // Note use of `input` rather than `rest` here.
+                if let Ok((rest, (selectors, body))) =
+                    pair(rule_start, body_block2)(input)
+                {
+                    return Ok((rest, Item::Rule(selectors, body)));
+                }
+            }
+            result
+        }
         b"" => {
-            let (input, selectors) = opt(rule_start)(input)?;
+            let (input, selectors) = opt(rule_start)(rest)?;
             match selectors {
                 Some(selectors) => map(body_block2, |body| {
                     Item::Rule(selectors.clone(), body)
@@ -477,9 +483,19 @@ fn return_stmt2(input: Span) -> PResult<Item> {
 
 /// The "rest" of an `@content` statement is just an optional terminator
 fn content_stmt2(input: Span) -> PResult<Item> {
-    let (input, _) = opt_spacelike(input)?;
-    let (input, _) = opt(tag(";"))(input)?;
-    Ok((input, Item::Content))
+    let (rest, _) = opt_spacelike(input)?;
+    let (rest, _) = opt(tag(";"))(rest)?;
+    let pos = SourcePos::from_to(input, rest);
+    Ok((rest, Item::Content(pos)))
+}
+
+fn custom_property(input: Span) -> PResult<Item> {
+    let (rest, name) = terminated(opt(sass_string), tag(":"))(input)?;
+    let mut name = name.unwrap_or_else(|| SassString::from(""));
+    name.prepend("--");
+    let (rest, value) =
+        terminated(custom_value, alt((tag(";"), peek(tag("}")))))(rest)?;
+    Ok((rest, Item::CustomProperty(name, value)))
 }
 
 fn property_or_namespace_rule(input: Span) -> PResult<Item> {
