@@ -1,3 +1,4 @@
+use super::css_function::css_function;
 use super::formalargs::call_args;
 use super::strings::{
     name, sass_string_dq, sass_string_ext, sass_string_sq,
@@ -304,7 +305,7 @@ fn sign_prefix(input: Span) -> PResult<Option<&[u8]>> {
         .map(|(r, s)| (r, s.map(|s| *s.fragment())))
 }
 
-fn number(input: Span) -> PResult<Value> {
+pub fn number(input: Span) -> PResult<Value> {
     map(
         tuple((
             sign_prefix,
@@ -362,36 +363,40 @@ pub fn decimal_decimals(input: Span) -> PResult<Number> {
 }
 
 pub fn variable(input: Span) -> PResult<Value> {
-    map(
-        pair(many0(terminated(name, tag("."))), preceded(tag("$"), name)),
-        |(modules, name)| {
-            if modules.is_empty() {
-                Value::Variable(name)
-            } else {
-                Value::Variable(format!("{}.{}", modules.join("."), name))
-            }
-        },
-    )(input)
+    let (rest, (modules, name)) = pair(
+        many0(terminated(name, tag("."))),
+        preceded(tag("$"), name),
+    )(input)?;
+    let name = if modules.is_empty() {
+        name
+    } else {
+        format!("{}.{}", modules.join("."), name)
+    };
+    let pos = SourcePos::from_to(input, rest);
+    Ok((rest, Value::Variable(name, pos)))
 }
 
 fn hex_color(input: Span) -> PResult<Value> {
-    let (rest, rgba) = delimited(
+    let (rest, (r, g, b, a)) = delimited(
         tag("#"),
-        map(
-            alt((
-                tuple((hexchar2, hexchar2, hexchar2, opt(hexchar2))),
-                tuple((hexchar1, hexchar1, hexchar1, opt(hexchar1))),
-            )),
-            |(r, g, b, a): (u8, u8, u8, Option<u8>)| {
-                Rgba::from_rgba(r, g, b, a.unwrap_or(255))
-            },
-        ),
+        alt((
+            tuple((hexchar2, hexchar2, hexchar2, opt(hexchar2))),
+            tuple((hexchar1, hexchar1, hexchar1, opt(hexchar1))),
+        )),
         peek(map(not(alphanumeric1), |_| ())),
     )(input)?;
-    let length = input.fragment().len() - rest.fragment().len();
-    // Unwrap should be ok as only ascii is matched.
-    let raw = from_utf8(&input.fragment()[0..length]).unwrap().to_string();
-    Ok((rest, Value::Color(rgba, Some(raw))))
+
+    if let Some(a) = a {
+        let rgba = Rgba::from_rgba(r, g, b, a);
+        Ok((rest, Value::Color(rgba, None)))
+    } else {
+        let rgba = Rgba::from_rgb(r, g, b);
+        let length = input.fragment().len() - rest.fragment().len();
+        // Unwrap should be ok as only ascii is matched.
+        let raw =
+            from_utf8(&input.fragment()[0..length]).unwrap().to_string();
+        Ok((rest, Value::Color(rgba, Some(raw))))
+    }
 }
 
 pub fn unary_op(input: Span) -> PResult<Value> {
@@ -412,8 +417,9 @@ pub fn unary_op(input: Span) -> PResult<Value> {
     )(input)
 }
 
-fn special_function(input: Span) -> PResult<Value> {
-    map(special_function_misc, Value::Literal)(input)
+pub fn special_function(input: Span) -> PResult<Value> {
+    // Either a nice semantic css function or a fallback with interpolation.
+    alt((css_function, map(special_function_misc, Value::Literal)))(input)
 }
 
 pub fn function_call(input: Span) -> PResult<Value> {
@@ -528,7 +534,13 @@ mod test {
 
     #[test]
     fn simple_value_variable() {
-        check_expr("$red;", Variable("red".into()))
+        match value_expression(code_span(b"$red;"))
+            .map(|(_, value)| value)
+            .unwrap()
+        {
+            Value::Variable(name, _) => assert_eq!(name, "red"),
+            val => panic!("Unexpected value {:?}", val),
+        }
     }
 
     #[test]
