@@ -24,7 +24,6 @@ fn main() -> Result<(), Error> {
             "core_functions/selector/is_superselector", // not supported
             "core_functions/selector/unify",  // not supported
             "directives/extend", // `@extend` is not supported at all
-            "libsass-closed-issues/issue_1801", // infinite recursion
             "libsass-todo-issues/issue_1801", // infinite recursion
             "libsass-todo-issues/issue_221262.hrx", // stack overflow
             "libsass-todo-issues/issue_221260.hrx", // stack overflow
@@ -77,7 +76,7 @@ fn handle_suite(
         let mut tr = File::create(rssuitedir.join("testrunner.rs"))?;
         tr.write_all(include_bytes!("testrunner.rs"))?;
     }
-    handle_entries(&mut rs, &base, &suitedir, &rssuitedir, None, ignored)
+    handle_entries(&mut rs, base, &suitedir, &rssuitedir, None, ignored)
         .map_err(|e| {
             Error(format!("Failed to handle suite {:?}: {}", suite, e))
         })
@@ -134,7 +133,7 @@ fn handle_entries(
                 if input.exists() {
                     spec_dir_to_test(
                         rs,
-                        &suitedir,
+                        suitedir,
                         &entry.file_name(),
                         precision,
                     )
@@ -184,7 +183,7 @@ fn handle_entries(
                             .collect();
                         handle_entries(
                             &mut rs,
-                            &root,
+                            root,
                             &entry.path(),
                             &rssuitedir,
                             precision,
@@ -304,7 +303,7 @@ fn handle_hrx_part(
     if archive.get(&format!("{}input.scss", prefix)).is_some() {
         let fixture = load_test_fixture_hrx(
             name.map(str::to_owned),
-            &archive,
+            archive,
             prefix,
             options,
         )?;
@@ -337,7 +336,7 @@ fn handle_hrx_part(
                 handle_hrx_part(
                     rs,
                     suite,
-                    &archive,
+                    archive,
                     &format!("{}{}", prefix, name),
                     options.precision,
                     runner.clone().with_cwd(name),
@@ -404,7 +403,7 @@ fn load_test_fixture_dir(
     static EXPECTED_ERROR_FILENAMES: &[&str] = &["error-dart-sass", "error"];
 
     let name = specdir.file_name().map(|s| s.to_string_lossy().to_string());
-    let mut options = load_options(&specdir)?;
+    let mut options = load_options(specdir)?;
     options.precision = options.precision.or(precision);
     let input = content(&specdir.join(INPUT_FILENAME))?;
 
