@@ -32,7 +32,7 @@ mod one_arg {
         assert_eq!(
             runner().ok("a {b: rgba(190 173 237)}\n"),
             "a {\
-         \n  b: #beaded;\
+         \n  b: rgb(190, 173, 237);\
          \n}\n"
         );
     }
@@ -42,7 +42,7 @@ fn three_args() {
     assert_eq!(
         runner().ok("a {b: rgba(190, 173, 237)}\n"),
         "a {\
-         \n  b: #beaded;\
+         \n  b: rgb(190, 173, 237);\
          \n}\n"
     );
 }
