@@ -50,7 +50,6 @@ mod core_module {
     }
 
     #[test]
-    #[ignore] // unexepected error
     fn indirect() {
         let runner = runner().with_cwd("indirect");
         assert_eq!(
@@ -64,7 +63,6 @@ mod core_module {
     }
 }
 #[test]
-#[ignore] // unexepected error
 fn dash_insensitive() {
     let runner = runner().with_cwd("dash_insensitive");
     assert_eq!(
@@ -78,7 +76,6 @@ fn dash_insensitive() {
     );
 }
 #[test]
-#[ignore] // unexepected error
 fn doesnt_run_default() {
     let runner = runner().with_cwd("doesnt_run_default");
     assert_eq!(
@@ -90,7 +87,6 @@ fn doesnt_run_default() {
     );
 }
 #[test]
-#[ignore] // unexepected error
 fn empty() {
     let runner = runner().with_cwd("empty");
     assert_eq!(
@@ -108,7 +104,7 @@ mod multi_load {
     }
 
     #[test]
-    #[ignore] // unexepected error
+    #[ignore] // wrong result
     fn empty() {
         let runner = runner().with_cwd("empty");
         assert_eq!(
@@ -124,7 +120,7 @@ mod multi_load {
     );
     }
     #[test]
-    #[ignore] // unexepected error
+    #[ignore] // wrong result
     fn forward() {
         let runner = runner().with_cwd("forward");
         assert_eq!(
@@ -141,7 +137,7 @@ mod multi_load {
     );
     }
     #[test]
-    #[ignore] // unexepected error
+    #[ignore] // wrong result
     fn test_use() {
         let runner = runner().with_cwd("use");
         assert_eq!(
@@ -159,7 +155,6 @@ mod multi_load {
     }
 }
 #[test]
-#[ignore] // unexepected error
 fn multiple() {
     let runner = runner().with_cwd("multiple");
     assert_eq!(
@@ -177,7 +172,6 @@ fn multiple() {
     );
 }
 #[test]
-#[ignore] // unexepected error
 fn null() {
     let runner = runner().with_cwd("null");
     assert_eq!(
@@ -189,7 +183,6 @@ fn null() {
     );
 }
 #[test]
-#[ignore] // unexepected error
 fn single() {
     let runner = runner().with_cwd("single");
     assert_eq!(
@@ -201,7 +194,6 @@ fn single() {
     );
 }
 #[test]
-#[ignore] // unexepected error
 fn some_unconfigured() {
     let runner = runner().with_cwd("some_unconfigured");
     assert_eq!(
@@ -222,7 +214,7 @@ mod through_forward {
     }
 
     #[test]
-    #[ignore] // unexepected error
+    #[ignore] // wrong result
     fn test_as() {
         let runner = runner().with_cwd("as");
         assert_eq!(
@@ -236,7 +228,7 @@ mod through_forward {
     );
     }
     #[test]
-    #[ignore] // unexepected error
+    #[ignore] // wrong result
     fn bare() {
         let runner = runner().with_cwd("bare");
         assert_eq!(
@@ -250,7 +242,7 @@ mod through_forward {
         );
     }
     #[test]
-    #[ignore] // unexepected error
+    #[ignore] // wrong result
     fn hide() {
         let runner = runner().with_cwd("hide");
         assert_eq!(
@@ -264,7 +256,7 @@ mod through_forward {
         );
     }
     #[test]
-    #[ignore] // unexepected error
+    #[ignore] // wrong result
     fn show() {
         let runner = runner().with_cwd("show");
         assert_eq!(
@@ -278,7 +270,7 @@ mod through_forward {
         );
     }
     #[test]
-    #[ignore] // unexepected error
+    #[ignore] // wrong result
     fn transitive() {
         let runner = runner().with_cwd("transitive");
         assert_eq!(
@@ -298,7 +290,6 @@ mod through_forward {
         }
 
         #[test]
-        #[ignore] // unexepected error
         fn default() {
             let runner = runner().with_cwd("default");
             assert_eq!(
@@ -312,7 +303,7 @@ mod through_forward {
             );
         }
         #[test]
-        #[ignore] // unexepected error
+        #[ignore] // wrong result
         fn null() {
             let runner = runner().with_cwd("null");
             assert_eq!(
@@ -324,7 +315,7 @@ mod through_forward {
             );
         }
         #[test]
-        #[ignore] // unexepected error
+        #[ignore] // wrong result
         fn unconfigured() {
             let runner = runner().with_cwd("unconfigured");
             assert_eq!(
@@ -347,7 +338,6 @@ mod through_import {
     }
 
     #[test]
-    #[ignore] // unexepected error
     fn direct() {
         let runner = runner().with_cwd("direct");
         assert_eq!(
@@ -361,7 +351,6 @@ mod through_import {
         );
     }
     #[test]
-    #[ignore] // unexepected error
     fn transitive() {
         let runner = runner().with_cwd("transitive");
         assert_eq!(
@@ -376,7 +365,7 @@ mod through_import {
     }
 }
 #[test]
-#[ignore] // unexepected error
+#[ignore] // wrong result
 fn variable_exists() {
     let runner = runner().with_cwd("variable_exists");
     assert_eq!(
