@@ -374,369 +374,369 @@ fn test() {
              \n  c101: rgb(0,0,101%);\
              \n}\n"),
         "foo {\
-         \n  c-1: black;\
-         \n  c0: black;\
-         \n  c1: #000001;\
-         \n  c2: #000002;\
-         \n  c3: #000003;\
-         \n  c4: #000004;\
-         \n  c5: #000005;\
-         \n  c6: #000006;\
-         \n  c7: #000007;\
-         \n  c8: #000008;\
-         \n  c9: #000009;\
-         \n  c10: #00000a;\
-         \n  c11: #00000b;\
-         \n  c12: #00000c;\
-         \n  c13: #00000d;\
-         \n  c14: #00000e;\
-         \n  c15: #00000f;\
-         \n  c16: #000010;\
-         \n  c17: #000011;\
-         \n  c18: #000012;\
-         \n  c19: #000013;\
-         \n  c20: #000014;\
-         \n  c21: #000015;\
-         \n  c22: #000016;\
-         \n  c23: #000017;\
-         \n  c24: #000018;\
-         \n  c25: #000019;\
-         \n  c26: #00001a;\
-         \n  c27: #00001b;\
-         \n  c28: #00001c;\
-         \n  c29: #00001d;\
-         \n  c30: #00001e;\
-         \n  c31: #00001f;\
-         \n  c32: #000020;\
-         \n  c33: #000021;\
-         \n  c34: #000022;\
-         \n  c35: #000023;\
-         \n  c36: #000024;\
-         \n  c37: #000025;\
-         \n  c38: #000026;\
-         \n  c39: #000027;\
-         \n  c40: #000028;\
-         \n  c41: #000029;\
-         \n  c42: #00002a;\
-         \n  c43: #00002b;\
-         \n  c44: #00002c;\
-         \n  c45: #00002d;\
-         \n  c46: #00002e;\
-         \n  c47: #00002f;\
-         \n  c48: #000030;\
-         \n  c49: #000031;\
-         \n  c50: #000032;\
-         \n  c51: #000033;\
-         \n  c52: #000034;\
-         \n  c53: #000035;\
-         \n  c54: #000036;\
-         \n  c55: #000037;\
-         \n  c56: #000038;\
-         \n  c57: #000039;\
-         \n  c58: #00003a;\
-         \n  c59: #00003b;\
-         \n  c60: #00003c;\
-         \n  c61: #00003d;\
-         \n  c62: #00003e;\
-         \n  c63: #00003f;\
-         \n  c64: #000040;\
-         \n  c65: #000041;\
-         \n  c66: #000042;\
-         \n  c67: #000043;\
-         \n  c68: #000044;\
-         \n  c69: #000045;\
-         \n  c70: #000046;\
-         \n  c71: #000047;\
-         \n  c72: #000048;\
-         \n  c73: #000049;\
-         \n  c74: #00004a;\
-         \n  c75: #00004b;\
-         \n  c76: #00004c;\
-         \n  c77: #00004d;\
-         \n  c78: #00004e;\
-         \n  c79: #00004f;\
-         \n  c80: #000050;\
-         \n  c81: #000051;\
-         \n  c82: #000052;\
-         \n  c83: #000053;\
-         \n  c84: #000054;\
-         \n  c85: #000055;\
-         \n  c86: #000056;\
-         \n  c87: #000057;\
-         \n  c88: #000058;\
-         \n  c89: #000059;\
-         \n  c90: #00005a;\
-         \n  c91: #00005b;\
-         \n  c92: #00005c;\
-         \n  c93: #00005d;\
-         \n  c94: #00005e;\
-         \n  c95: #00005f;\
-         \n  c96: #000060;\
-         \n  c97: #000061;\
-         \n  c98: #000062;\
-         \n  c99: #000063;\
-         \n  c100: #000064;\
-         \n  c101: #000065;\
-         \n  c102: #000066;\
-         \n  c103: #000067;\
-         \n  c104: #000068;\
-         \n  c105: #000069;\
-         \n  c106: #00006a;\
-         \n  c107: #00006b;\
-         \n  c108: #00006c;\
-         \n  c109: #00006d;\
-         \n  c110: #00006e;\
-         \n  c111: #00006f;\
-         \n  c112: #000070;\
-         \n  c113: #000071;\
-         \n  c114: #000072;\
-         \n  c115: #000073;\
-         \n  c116: #000074;\
-         \n  c117: #000075;\
-         \n  c118: #000076;\
-         \n  c119: #000077;\
-         \n  c120: #000078;\
-         \n  c121: #000079;\
-         \n  c122: #00007a;\
-         \n  c123: #00007b;\
-         \n  c124: #00007c;\
-         \n  c125: #00007d;\
-         \n  c126: #00007e;\
-         \n  c127: #00007f;\
-         \n  c128: navy;\
-         \n  c129: #000081;\
-         \n  c130: #000082;\
-         \n  c131: #000083;\
-         \n  c132: #000084;\
-         \n  c133: #000085;\
-         \n  c134: #000086;\
-         \n  c135: #000087;\
-         \n  c136: #000088;\
-         \n  c137: #000089;\
-         \n  c138: #00008a;\
-         \n  c139: darkblue;\
-         \n  c140: #00008c;\
-         \n  c141: #00008d;\
-         \n  c142: #00008e;\
-         \n  c143: #00008f;\
-         \n  c144: #000090;\
-         \n  c145: #000091;\
-         \n  c146: #000092;\
-         \n  c147: #000093;\
-         \n  c148: #000094;\
-         \n  c149: #000095;\
-         \n  c150: #000096;\
-         \n  c151: #000097;\
-         \n  c152: #000098;\
-         \n  c153: #000099;\
-         \n  c154: #00009a;\
-         \n  c155: #00009b;\
-         \n  c156: #00009c;\
-         \n  c157: #00009d;\
-         \n  c158: #00009e;\
-         \n  c159: #00009f;\
-         \n  c160: #0000a0;\
-         \n  c161: #0000a1;\
-         \n  c162: #0000a2;\
-         \n  c163: #0000a3;\
-         \n  c164: #0000a4;\
-         \n  c165: #0000a5;\
-         \n  c166: #0000a6;\
-         \n  c167: #0000a7;\
-         \n  c168: #0000a8;\
-         \n  c169: #0000a9;\
-         \n  c170: #0000aa;\
-         \n  c171: #0000ab;\
-         \n  c172: #0000ac;\
-         \n  c173: #0000ad;\
-         \n  c174: #0000ae;\
-         \n  c175: #0000af;\
-         \n  c176: #0000b0;\
-         \n  c177: #0000b1;\
-         \n  c178: #0000b2;\
-         \n  c179: #0000b3;\
-         \n  c180: #0000b4;\
-         \n  c181: #0000b5;\
-         \n  c182: #0000b6;\
-         \n  c183: #0000b7;\
-         \n  c184: #0000b8;\
-         \n  c185: #0000b9;\
-         \n  c186: #0000ba;\
-         \n  c187: #0000bb;\
-         \n  c188: #0000bc;\
-         \n  c189: #0000bd;\
-         \n  c190: #0000be;\
-         \n  c191: #0000bf;\
-         \n  c192: #0000c0;\
-         \n  c193: #0000c1;\
-         \n  c194: #0000c2;\
-         \n  c195: #0000c3;\
-         \n  c196: #0000c4;\
-         \n  c197: #0000c5;\
-         \n  c198: #0000c6;\
-         \n  c199: #0000c7;\
-         \n  c200: #0000c8;\
-         \n  c201: #0000c9;\
-         \n  c202: #0000ca;\
-         \n  c203: #0000cb;\
-         \n  c204: #0000cc;\
-         \n  c205: mediumblue;\
-         \n  c206: #0000ce;\
-         \n  c207: #0000cf;\
-         \n  c208: #0000d0;\
-         \n  c209: #0000d1;\
-         \n  c210: #0000d2;\
-         \n  c211: #0000d3;\
-         \n  c212: #0000d4;\
-         \n  c213: #0000d5;\
-         \n  c214: #0000d6;\
-         \n  c215: #0000d7;\
-         \n  c216: #0000d8;\
-         \n  c217: #0000d9;\
-         \n  c218: #0000da;\
-         \n  c219: #0000db;\
-         \n  c220: #0000dc;\
-         \n  c221: #0000dd;\
-         \n  c222: #0000de;\
-         \n  c223: #0000df;\
-         \n  c224: #0000e0;\
-         \n  c225: #0000e1;\
-         \n  c226: #0000e2;\
-         \n  c227: #0000e3;\
-         \n  c228: #0000e4;\
-         \n  c229: #0000e5;\
-         \n  c230: #0000e6;\
-         \n  c231: #0000e7;\
-         \n  c232: #0000e8;\
-         \n  c233: #0000e9;\
-         \n  c234: #0000ea;\
-         \n  c235: #0000eb;\
-         \n  c236: #0000ec;\
-         \n  c237: #0000ed;\
-         \n  c238: #0000ee;\
-         \n  c239: #0000ef;\
-         \n  c240: #0000f0;\
-         \n  c241: #0000f1;\
-         \n  c242: #0000f2;\
-         \n  c243: #0000f3;\
-         \n  c244: #0000f4;\
-         \n  c245: #0000f5;\
-         \n  c246: #0000f6;\
-         \n  c247: #0000f7;\
-         \n  c248: #0000f8;\
-         \n  c249: #0000f9;\
-         \n  c250: #0000fa;\
-         \n  c251: #0000fb;\
-         \n  c252: #0000fc;\
-         \n  c253: #0000fd;\
-         \n  c254: #0000fe;\
-         \n  c255: blue;\
-         \n  c256: blue;\
+         \n  c-1: rgb(0, 0, 0);\
+         \n  c0: rgb(0, 0, 0);\
+         \n  c1: rgb(0, 0, 1);\
+         \n  c2: rgb(0, 0, 2);\
+         \n  c3: rgb(0, 0, 3);\
+         \n  c4: rgb(0, 0, 4);\
+         \n  c5: rgb(0, 0, 5);\
+         \n  c6: rgb(0, 0, 6);\
+         \n  c7: rgb(0, 0, 7);\
+         \n  c8: rgb(0, 0, 8);\
+         \n  c9: rgb(0, 0, 9);\
+         \n  c10: rgb(0, 0, 10);\
+         \n  c11: rgb(0, 0, 11);\
+         \n  c12: rgb(0, 0, 12);\
+         \n  c13: rgb(0, 0, 13);\
+         \n  c14: rgb(0, 0, 14);\
+         \n  c15: rgb(0, 0, 15);\
+         \n  c16: rgb(0, 0, 16);\
+         \n  c17: rgb(0, 0, 17);\
+         \n  c18: rgb(0, 0, 18);\
+         \n  c19: rgb(0, 0, 19);\
+         \n  c20: rgb(0, 0, 20);\
+         \n  c21: rgb(0, 0, 21);\
+         \n  c22: rgb(0, 0, 22);\
+         \n  c23: rgb(0, 0, 23);\
+         \n  c24: rgb(0, 0, 24);\
+         \n  c25: rgb(0, 0, 25);\
+         \n  c26: rgb(0, 0, 26);\
+         \n  c27: rgb(0, 0, 27);\
+         \n  c28: rgb(0, 0, 28);\
+         \n  c29: rgb(0, 0, 29);\
+         \n  c30: rgb(0, 0, 30);\
+         \n  c31: rgb(0, 0, 31);\
+         \n  c32: rgb(0, 0, 32);\
+         \n  c33: rgb(0, 0, 33);\
+         \n  c34: rgb(0, 0, 34);\
+         \n  c35: rgb(0, 0, 35);\
+         \n  c36: rgb(0, 0, 36);\
+         \n  c37: rgb(0, 0, 37);\
+         \n  c38: rgb(0, 0, 38);\
+         \n  c39: rgb(0, 0, 39);\
+         \n  c40: rgb(0, 0, 40);\
+         \n  c41: rgb(0, 0, 41);\
+         \n  c42: rgb(0, 0, 42);\
+         \n  c43: rgb(0, 0, 43);\
+         \n  c44: rgb(0, 0, 44);\
+         \n  c45: rgb(0, 0, 45);\
+         \n  c46: rgb(0, 0, 46);\
+         \n  c47: rgb(0, 0, 47);\
+         \n  c48: rgb(0, 0, 48);\
+         \n  c49: rgb(0, 0, 49);\
+         \n  c50: rgb(0, 0, 50);\
+         \n  c51: rgb(0, 0, 51);\
+         \n  c52: rgb(0, 0, 52);\
+         \n  c53: rgb(0, 0, 53);\
+         \n  c54: rgb(0, 0, 54);\
+         \n  c55: rgb(0, 0, 55);\
+         \n  c56: rgb(0, 0, 56);\
+         \n  c57: rgb(0, 0, 57);\
+         \n  c58: rgb(0, 0, 58);\
+         \n  c59: rgb(0, 0, 59);\
+         \n  c60: rgb(0, 0, 60);\
+         \n  c61: rgb(0, 0, 61);\
+         \n  c62: rgb(0, 0, 62);\
+         \n  c63: rgb(0, 0, 63);\
+         \n  c64: rgb(0, 0, 64);\
+         \n  c65: rgb(0, 0, 65);\
+         \n  c66: rgb(0, 0, 66);\
+         \n  c67: rgb(0, 0, 67);\
+         \n  c68: rgb(0, 0, 68);\
+         \n  c69: rgb(0, 0, 69);\
+         \n  c70: rgb(0, 0, 70);\
+         \n  c71: rgb(0, 0, 71);\
+         \n  c72: rgb(0, 0, 72);\
+         \n  c73: rgb(0, 0, 73);\
+         \n  c74: rgb(0, 0, 74);\
+         \n  c75: rgb(0, 0, 75);\
+         \n  c76: rgb(0, 0, 76);\
+         \n  c77: rgb(0, 0, 77);\
+         \n  c78: rgb(0, 0, 78);\
+         \n  c79: rgb(0, 0, 79);\
+         \n  c80: rgb(0, 0, 80);\
+         \n  c81: rgb(0, 0, 81);\
+         \n  c82: rgb(0, 0, 82);\
+         \n  c83: rgb(0, 0, 83);\
+         \n  c84: rgb(0, 0, 84);\
+         \n  c85: rgb(0, 0, 85);\
+         \n  c86: rgb(0, 0, 86);\
+         \n  c87: rgb(0, 0, 87);\
+         \n  c88: rgb(0, 0, 88);\
+         \n  c89: rgb(0, 0, 89);\
+         \n  c90: rgb(0, 0, 90);\
+         \n  c91: rgb(0, 0, 91);\
+         \n  c92: rgb(0, 0, 92);\
+         \n  c93: rgb(0, 0, 93);\
+         \n  c94: rgb(0, 0, 94);\
+         \n  c95: rgb(0, 0, 95);\
+         \n  c96: rgb(0, 0, 96);\
+         \n  c97: rgb(0, 0, 97);\
+         \n  c98: rgb(0, 0, 98);\
+         \n  c99: rgb(0, 0, 99);\
+         \n  c100: rgb(0, 0, 100);\
+         \n  c101: rgb(0, 0, 101);\
+         \n  c102: rgb(0, 0, 102);\
+         \n  c103: rgb(0, 0, 103);\
+         \n  c104: rgb(0, 0, 104);\
+         \n  c105: rgb(0, 0, 105);\
+         \n  c106: rgb(0, 0, 106);\
+         \n  c107: rgb(0, 0, 107);\
+         \n  c108: rgb(0, 0, 108);\
+         \n  c109: rgb(0, 0, 109);\
+         \n  c110: rgb(0, 0, 110);\
+         \n  c111: rgb(0, 0, 111);\
+         \n  c112: rgb(0, 0, 112);\
+         \n  c113: rgb(0, 0, 113);\
+         \n  c114: rgb(0, 0, 114);\
+         \n  c115: rgb(0, 0, 115);\
+         \n  c116: rgb(0, 0, 116);\
+         \n  c117: rgb(0, 0, 117);\
+         \n  c118: rgb(0, 0, 118);\
+         \n  c119: rgb(0, 0, 119);\
+         \n  c120: rgb(0, 0, 120);\
+         \n  c121: rgb(0, 0, 121);\
+         \n  c122: rgb(0, 0, 122);\
+         \n  c123: rgb(0, 0, 123);\
+         \n  c124: rgb(0, 0, 124);\
+         \n  c125: rgb(0, 0, 125);\
+         \n  c126: rgb(0, 0, 126);\
+         \n  c127: rgb(0, 0, 127);\
+         \n  c128: rgb(0, 0, 128);\
+         \n  c129: rgb(0, 0, 129);\
+         \n  c130: rgb(0, 0, 130);\
+         \n  c131: rgb(0, 0, 131);\
+         \n  c132: rgb(0, 0, 132);\
+         \n  c133: rgb(0, 0, 133);\
+         \n  c134: rgb(0, 0, 134);\
+         \n  c135: rgb(0, 0, 135);\
+         \n  c136: rgb(0, 0, 136);\
+         \n  c137: rgb(0, 0, 137);\
+         \n  c138: rgb(0, 0, 138);\
+         \n  c139: rgb(0, 0, 139);\
+         \n  c140: rgb(0, 0, 140);\
+         \n  c141: rgb(0, 0, 141);\
+         \n  c142: rgb(0, 0, 142);\
+         \n  c143: rgb(0, 0, 143);\
+         \n  c144: rgb(0, 0, 144);\
+         \n  c145: rgb(0, 0, 145);\
+         \n  c146: rgb(0, 0, 146);\
+         \n  c147: rgb(0, 0, 147);\
+         \n  c148: rgb(0, 0, 148);\
+         \n  c149: rgb(0, 0, 149);\
+         \n  c150: rgb(0, 0, 150);\
+         \n  c151: rgb(0, 0, 151);\
+         \n  c152: rgb(0, 0, 152);\
+         \n  c153: rgb(0, 0, 153);\
+         \n  c154: rgb(0, 0, 154);\
+         \n  c155: rgb(0, 0, 155);\
+         \n  c156: rgb(0, 0, 156);\
+         \n  c157: rgb(0, 0, 157);\
+         \n  c158: rgb(0, 0, 158);\
+         \n  c159: rgb(0, 0, 159);\
+         \n  c160: rgb(0, 0, 160);\
+         \n  c161: rgb(0, 0, 161);\
+         \n  c162: rgb(0, 0, 162);\
+         \n  c163: rgb(0, 0, 163);\
+         \n  c164: rgb(0, 0, 164);\
+         \n  c165: rgb(0, 0, 165);\
+         \n  c166: rgb(0, 0, 166);\
+         \n  c167: rgb(0, 0, 167);\
+         \n  c168: rgb(0, 0, 168);\
+         \n  c169: rgb(0, 0, 169);\
+         \n  c170: rgb(0, 0, 170);\
+         \n  c171: rgb(0, 0, 171);\
+         \n  c172: rgb(0, 0, 172);\
+         \n  c173: rgb(0, 0, 173);\
+         \n  c174: rgb(0, 0, 174);\
+         \n  c175: rgb(0, 0, 175);\
+         \n  c176: rgb(0, 0, 176);\
+         \n  c177: rgb(0, 0, 177);\
+         \n  c178: rgb(0, 0, 178);\
+         \n  c179: rgb(0, 0, 179);\
+         \n  c180: rgb(0, 0, 180);\
+         \n  c181: rgb(0, 0, 181);\
+         \n  c182: rgb(0, 0, 182);\
+         \n  c183: rgb(0, 0, 183);\
+         \n  c184: rgb(0, 0, 184);\
+         \n  c185: rgb(0, 0, 185);\
+         \n  c186: rgb(0, 0, 186);\
+         \n  c187: rgb(0, 0, 187);\
+         \n  c188: rgb(0, 0, 188);\
+         \n  c189: rgb(0, 0, 189);\
+         \n  c190: rgb(0, 0, 190);\
+         \n  c191: rgb(0, 0, 191);\
+         \n  c192: rgb(0, 0, 192);\
+         \n  c193: rgb(0, 0, 193);\
+         \n  c194: rgb(0, 0, 194);\
+         \n  c195: rgb(0, 0, 195);\
+         \n  c196: rgb(0, 0, 196);\
+         \n  c197: rgb(0, 0, 197);\
+         \n  c198: rgb(0, 0, 198);\
+         \n  c199: rgb(0, 0, 199);\
+         \n  c200: rgb(0, 0, 200);\
+         \n  c201: rgb(0, 0, 201);\
+         \n  c202: rgb(0, 0, 202);\
+         \n  c203: rgb(0, 0, 203);\
+         \n  c204: rgb(0, 0, 204);\
+         \n  c205: rgb(0, 0, 205);\
+         \n  c206: rgb(0, 0, 206);\
+         \n  c207: rgb(0, 0, 207);\
+         \n  c208: rgb(0, 0, 208);\
+         \n  c209: rgb(0, 0, 209);\
+         \n  c210: rgb(0, 0, 210);\
+         \n  c211: rgb(0, 0, 211);\
+         \n  c212: rgb(0, 0, 212);\
+         \n  c213: rgb(0, 0, 213);\
+         \n  c214: rgb(0, 0, 214);\
+         \n  c215: rgb(0, 0, 215);\
+         \n  c216: rgb(0, 0, 216);\
+         \n  c217: rgb(0, 0, 217);\
+         \n  c218: rgb(0, 0, 218);\
+         \n  c219: rgb(0, 0, 219);\
+         \n  c220: rgb(0, 0, 220);\
+         \n  c221: rgb(0, 0, 221);\
+         \n  c222: rgb(0, 0, 222);\
+         \n  c223: rgb(0, 0, 223);\
+         \n  c224: rgb(0, 0, 224);\
+         \n  c225: rgb(0, 0, 225);\
+         \n  c226: rgb(0, 0, 226);\
+         \n  c227: rgb(0, 0, 227);\
+         \n  c228: rgb(0, 0, 228);\
+         \n  c229: rgb(0, 0, 229);\
+         \n  c230: rgb(0, 0, 230);\
+         \n  c231: rgb(0, 0, 231);\
+         \n  c232: rgb(0, 0, 232);\
+         \n  c233: rgb(0, 0, 233);\
+         \n  c234: rgb(0, 0, 234);\
+         \n  c235: rgb(0, 0, 235);\
+         \n  c236: rgb(0, 0, 236);\
+         \n  c237: rgb(0, 0, 237);\
+         \n  c238: rgb(0, 0, 238);\
+         \n  c239: rgb(0, 0, 239);\
+         \n  c240: rgb(0, 0, 240);\
+         \n  c241: rgb(0, 0, 241);\
+         \n  c242: rgb(0, 0, 242);\
+         \n  c243: rgb(0, 0, 243);\
+         \n  c244: rgb(0, 0, 244);\
+         \n  c245: rgb(0, 0, 245);\
+         \n  c246: rgb(0, 0, 246);\
+         \n  c247: rgb(0, 0, 247);\
+         \n  c248: rgb(0, 0, 248);\
+         \n  c249: rgb(0, 0, 249);\
+         \n  c250: rgb(0, 0, 250);\
+         \n  c251: rgb(0, 0, 251);\
+         \n  c252: rgb(0, 0, 252);\
+         \n  c253: rgb(0, 0, 253);\
+         \n  c254: rgb(0, 0, 254);\
+         \n  c255: rgb(0, 0, 255);\
+         \n  c256: rgb(0, 0, 255);\
          \n}\
          \nfoo {\
-         \n  c-1: black;\
-         \n  c0: black;\
-         \n  c1: #000003;\
-         \n  c2: #000005;\
-         \n  c3: #000008;\
-         \n  c4: #00000a;\
-         \n  c5: #00000d;\
-         \n  c6: #00000f;\
-         \n  c7: #000012;\
-         \n  c8: #000014;\
-         \n  c9: #000017;\
-         \n  c10: #00001a;\
-         \n  c11: #00001c;\
-         \n  c12: #00001f;\
-         \n  c13: #000021;\
-         \n  c14: #000024;\
-         \n  c15: #000026;\
-         \n  c16: #000029;\
-         \n  c17: #00002b;\
-         \n  c18: #00002e;\
-         \n  c19: #000030;\
-         \n  c20: #000033;\
-         \n  c21: #000036;\
-         \n  c22: #000038;\
-         \n  c23: #00003b;\
-         \n  c24: #00003d;\
-         \n  c25: #000040;\
-         \n  c26: #000042;\
-         \n  c27: #000045;\
-         \n  c28: #000047;\
-         \n  c29: #00004a;\
-         \n  c30: #00004d;\
-         \n  c31: #00004f;\
-         \n  c32: #000052;\
-         \n  c33: #000054;\
-         \n  c34: #000057;\
-         \n  c35: #000059;\
-         \n  c36: #00005c;\
-         \n  c37: #00005e;\
-         \n  c38: #000061;\
-         \n  c39: #000063;\
-         \n  c40: #000066;\
-         \n  c41: #000069;\
-         \n  c42: #00006b;\
-         \n  c43: #00006e;\
-         \n  c44: #000070;\
-         \n  c45: #000073;\
-         \n  c46: #000075;\
-         \n  c47: #000078;\
-         \n  c48: #00007a;\
-         \n  c49: #00007d;\
-         \n  c50: navy;\
-         \n  c51: #000082;\
-         \n  c52: #000085;\
-         \n  c53: #000087;\
-         \n  c54: #00008a;\
-         \n  c55: #00008c;\
-         \n  c56: #00008f;\
-         \n  c57: #000091;\
-         \n  c58: #000094;\
-         \n  c59: #000096;\
-         \n  c60: #000099;\
-         \n  c61: #00009c;\
-         \n  c62: #00009e;\
-         \n  c63: #0000a1;\
-         \n  c64: #0000a3;\
-         \n  c65: #0000a6;\
-         \n  c66: #0000a8;\
-         \n  c67: #0000ab;\
-         \n  c68: #0000ad;\
-         \n  c69: #0000b0;\
-         \n  c70: #0000b3;\
-         \n  c71: #0000b5;\
-         \n  c72: #0000b8;\
-         \n  c73: #0000ba;\
-         \n  c74: #0000bd;\
-         \n  c75: #0000bf;\
-         \n  c76: #0000c2;\
-         \n  c77: #0000c4;\
-         \n  c78: #0000c7;\
-         \n  c79: #0000c9;\
-         \n  c80: #0000cc;\
-         \n  c81: #0000cf;\
-         \n  c82: #0000d1;\
-         \n  c83: #0000d4;\
-         \n  c84: #0000d6;\
-         \n  c85: #0000d9;\
-         \n  c86: #0000db;\
-         \n  c87: #0000de;\
-         \n  c88: #0000e0;\
-         \n  c89: #0000e3;\
-         \n  c90: #0000e6;\
-         \n  c91: #0000e8;\
-         \n  c92: #0000eb;\
-         \n  c93: #0000ed;\
-         \n  c94: #0000f0;\
-         \n  c95: #0000f2;\
-         \n  c96: #0000f5;\
-         \n  c97: #0000f7;\
-         \n  c98: #0000fa;\
-         \n  c99: #0000fc;\
-         \n  c100: blue;\
-         \n  c101: blue;\
+         \n  c-1: rgb(0, 0, 0);\
+         \n  c0: rgb(0, 0, 0);\
+         \n  c1: rgb(0, 0, 3);\
+         \n  c2: rgb(0, 0, 5);\
+         \n  c3: rgb(0, 0, 8);\
+         \n  c4: rgb(0, 0, 10);\
+         \n  c5: rgb(0, 0, 13);\
+         \n  c6: rgb(0, 0, 15);\
+         \n  c7: rgb(0, 0, 18);\
+         \n  c8: rgb(0, 0, 20);\
+         \n  c9: rgb(0, 0, 23);\
+         \n  c10: rgb(0, 0, 26);\
+         \n  c11: rgb(0, 0, 28);\
+         \n  c12: rgb(0, 0, 31);\
+         \n  c13: rgb(0, 0, 33);\
+         \n  c14: rgb(0, 0, 36);\
+         \n  c15: rgb(0, 0, 38);\
+         \n  c16: rgb(0, 0, 41);\
+         \n  c17: rgb(0, 0, 43);\
+         \n  c18: rgb(0, 0, 46);\
+         \n  c19: rgb(0, 0, 48);\
+         \n  c20: rgb(0, 0, 51);\
+         \n  c21: rgb(0, 0, 54);\
+         \n  c22: rgb(0, 0, 56);\
+         \n  c23: rgb(0, 0, 59);\
+         \n  c24: rgb(0, 0, 61);\
+         \n  c25: rgb(0, 0, 64);\
+         \n  c26: rgb(0, 0, 66);\
+         \n  c27: rgb(0, 0, 69);\
+         \n  c28: rgb(0, 0, 71);\
+         \n  c29: rgb(0, 0, 74);\
+         \n  c30: rgb(0, 0, 77);\
+         \n  c31: rgb(0, 0, 79);\
+         \n  c32: rgb(0, 0, 82);\
+         \n  c33: rgb(0, 0, 84);\
+         \n  c34: rgb(0, 0, 87);\
+         \n  c35: rgb(0, 0, 89);\
+         \n  c36: rgb(0, 0, 92);\
+         \n  c37: rgb(0, 0, 94);\
+         \n  c38: rgb(0, 0, 97);\
+         \n  c39: rgb(0, 0, 99);\
+         \n  c40: rgb(0, 0, 102);\
+         \n  c41: rgb(0, 0, 105);\
+         \n  c42: rgb(0, 0, 107);\
+         \n  c43: rgb(0, 0, 110);\
+         \n  c44: rgb(0, 0, 112);\
+         \n  c45: rgb(0, 0, 115);\
+         \n  c46: rgb(0, 0, 117);\
+         \n  c47: rgb(0, 0, 120);\
+         \n  c48: rgb(0, 0, 122);\
+         \n  c49: rgb(0, 0, 125);\
+         \n  c50: rgb(0, 0, 128);\
+         \n  c51: rgb(0, 0, 130);\
+         \n  c52: rgb(0, 0, 133);\
+         \n  c53: rgb(0, 0, 135);\
+         \n  c54: rgb(0, 0, 138);\
+         \n  c55: rgb(0, 0, 140);\
+         \n  c56: rgb(0, 0, 143);\
+         \n  c57: rgb(0, 0, 145);\
+         \n  c58: rgb(0, 0, 148);\
+         \n  c59: rgb(0, 0, 150);\
+         \n  c60: rgb(0, 0, 153);\
+         \n  c61: rgb(0, 0, 156);\
+         \n  c62: rgb(0, 0, 158);\
+         \n  c63: rgb(0, 0, 161);\
+         \n  c64: rgb(0, 0, 163);\
+         \n  c65: rgb(0, 0, 166);\
+         \n  c66: rgb(0, 0, 168);\
+         \n  c67: rgb(0, 0, 171);\
+         \n  c68: rgb(0, 0, 173);\
+         \n  c69: rgb(0, 0, 176);\
+         \n  c70: rgb(0, 0, 179);\
+         \n  c71: rgb(0, 0, 181);\
+         \n  c72: rgb(0, 0, 184);\
+         \n  c73: rgb(0, 0, 186);\
+         \n  c74: rgb(0, 0, 189);\
+         \n  c75: rgb(0, 0, 191);\
+         \n  c76: rgb(0, 0, 194);\
+         \n  c77: rgb(0, 0, 196);\
+         \n  c78: rgb(0, 0, 199);\
+         \n  c79: rgb(0, 0, 201);\
+         \n  c80: rgb(0, 0, 204);\
+         \n  c81: rgb(0, 0, 207);\
+         \n  c82: rgb(0, 0, 209);\
+         \n  c83: rgb(0, 0, 212);\
+         \n  c84: rgb(0, 0, 214);\
+         \n  c85: rgb(0, 0, 217);\
+         \n  c86: rgb(0, 0, 219);\
+         \n  c87: rgb(0, 0, 222);\
+         \n  c88: rgb(0, 0, 224);\
+         \n  c89: rgb(0, 0, 227);\
+         \n  c90: rgb(0, 0, 230);\
+         \n  c91: rgb(0, 0, 232);\
+         \n  c92: rgb(0, 0, 235);\
+         \n  c93: rgb(0, 0, 237);\
+         \n  c94: rgb(0, 0, 240);\
+         \n  c95: rgb(0, 0, 242);\
+         \n  c96: rgb(0, 0, 245);\
+         \n  c97: rgb(0, 0, 247);\
+         \n  c98: rgb(0, 0, 250);\
+         \n  c99: rgb(0, 0, 252);\
+         \n  c100: rgb(0, 0, 255);\
+         \n  c101: rgb(0, 0, 255);\
          \n}\n"
     );
 }
