@@ -374,369 +374,369 @@ fn test() {
              \n  c101: rgb(101%,0,0);\
              \n}\n"),
         "foo {\
-         \n  c-1: black;\
-         \n  c0: black;\
-         \n  c1: #000100;\
-         \n  c2: #000200;\
-         \n  c3: #000300;\
-         \n  c4: #000400;\
-         \n  c5: #000500;\
-         \n  c6: #000600;\
-         \n  c7: #000700;\
-         \n  c8: #000800;\
-         \n  c9: #000900;\
-         \n  c10: #000a00;\
-         \n  c11: #000b00;\
-         \n  c12: #000c00;\
-         \n  c13: #000d00;\
-         \n  c14: #000e00;\
-         \n  c15: #000f00;\
-         \n  c16: #001000;\
-         \n  c17: #001100;\
-         \n  c18: #001200;\
-         \n  c19: #001300;\
-         \n  c20: #001400;\
-         \n  c21: #001500;\
-         \n  c22: #001600;\
-         \n  c23: #001700;\
-         \n  c24: #001800;\
-         \n  c25: #001900;\
-         \n  c26: #001a00;\
-         \n  c27: #001b00;\
-         \n  c28: #001c00;\
-         \n  c29: #001d00;\
-         \n  c30: #001e00;\
-         \n  c31: #001f00;\
-         \n  c32: #002000;\
-         \n  c33: #002100;\
-         \n  c34: #002200;\
-         \n  c35: #002300;\
-         \n  c36: #002400;\
-         \n  c37: #002500;\
-         \n  c38: #002600;\
-         \n  c39: #002700;\
-         \n  c40: #002800;\
-         \n  c41: #002900;\
-         \n  c42: #002a00;\
-         \n  c43: #002b00;\
-         \n  c44: #002c00;\
-         \n  c45: #002d00;\
-         \n  c46: #002e00;\
-         \n  c47: #002f00;\
-         \n  c48: #003000;\
-         \n  c49: #003100;\
-         \n  c50: #003200;\
-         \n  c51: #003300;\
-         \n  c52: #003400;\
-         \n  c53: #003500;\
-         \n  c54: #003600;\
-         \n  c55: #003700;\
-         \n  c56: #003800;\
-         \n  c57: #003900;\
-         \n  c58: #003a00;\
-         \n  c59: #003b00;\
-         \n  c60: #003c00;\
-         \n  c61: #003d00;\
-         \n  c62: #003e00;\
-         \n  c63: #003f00;\
-         \n  c64: #004000;\
-         \n  c65: #004100;\
-         \n  c66: #004200;\
-         \n  c67: #004300;\
-         \n  c68: #004400;\
-         \n  c69: #004500;\
-         \n  c70: #004600;\
-         \n  c71: #004700;\
-         \n  c72: #004800;\
-         \n  c73: #004900;\
-         \n  c74: #004a00;\
-         \n  c75: #004b00;\
-         \n  c76: #004c00;\
-         \n  c77: #004d00;\
-         \n  c78: #004e00;\
-         \n  c79: #004f00;\
-         \n  c80: #005000;\
-         \n  c81: #005100;\
-         \n  c82: #005200;\
-         \n  c83: #005300;\
-         \n  c84: #005400;\
-         \n  c85: #005500;\
-         \n  c86: #005600;\
-         \n  c87: #005700;\
-         \n  c88: #005800;\
-         \n  c89: #005900;\
-         \n  c90: #005a00;\
-         \n  c91: #005b00;\
-         \n  c92: #005c00;\
-         \n  c93: #005d00;\
-         \n  c94: #005e00;\
-         \n  c95: #005f00;\
-         \n  c96: #006000;\
-         \n  c97: #006100;\
-         \n  c98: #006200;\
-         \n  c99: #006300;\
-         \n  c100: darkgreen;\
-         \n  c101: #006500;\
-         \n  c102: #006600;\
-         \n  c103: #006700;\
-         \n  c104: #006800;\
-         \n  c105: #006900;\
-         \n  c106: #006a00;\
-         \n  c107: #006b00;\
-         \n  c108: #006c00;\
-         \n  c109: #006d00;\
-         \n  c110: #006e00;\
-         \n  c111: #006f00;\
-         \n  c112: #007000;\
-         \n  c113: #007100;\
-         \n  c114: #007200;\
-         \n  c115: #007300;\
-         \n  c116: #007400;\
-         \n  c117: #007500;\
-         \n  c118: #007600;\
-         \n  c119: #007700;\
-         \n  c120: #007800;\
-         \n  c121: #007900;\
-         \n  c122: #007a00;\
-         \n  c123: #007b00;\
-         \n  c124: #007c00;\
-         \n  c125: #007d00;\
-         \n  c126: #007e00;\
-         \n  c127: #007f00;\
-         \n  c128: green;\
-         \n  c129: #008100;\
-         \n  c130: #008200;\
-         \n  c131: #008300;\
-         \n  c132: #008400;\
-         \n  c133: #008500;\
-         \n  c134: #008600;\
-         \n  c135: #008700;\
-         \n  c136: #008800;\
-         \n  c137: #008900;\
-         \n  c138: #008a00;\
-         \n  c139: #008b00;\
-         \n  c140: #008c00;\
-         \n  c141: #008d00;\
-         \n  c142: #008e00;\
-         \n  c143: #008f00;\
-         \n  c144: #009000;\
-         \n  c145: #009100;\
-         \n  c146: #009200;\
-         \n  c147: #009300;\
-         \n  c148: #009400;\
-         \n  c149: #009500;\
-         \n  c150: #009600;\
-         \n  c151: #009700;\
-         \n  c152: #009800;\
-         \n  c153: #009900;\
-         \n  c154: #009a00;\
-         \n  c155: #009b00;\
-         \n  c156: #009c00;\
-         \n  c157: #009d00;\
-         \n  c158: #009e00;\
-         \n  c159: #009f00;\
-         \n  c160: #00a000;\
-         \n  c161: #00a100;\
-         \n  c162: #00a200;\
-         \n  c163: #00a300;\
-         \n  c164: #00a400;\
-         \n  c165: #00a500;\
-         \n  c166: #00a600;\
-         \n  c167: #00a700;\
-         \n  c168: #00a800;\
-         \n  c169: #00a900;\
-         \n  c170: #00aa00;\
-         \n  c171: #00ab00;\
-         \n  c172: #00ac00;\
-         \n  c173: #00ad00;\
-         \n  c174: #00ae00;\
-         \n  c175: #00af00;\
-         \n  c176: #00b000;\
-         \n  c177: #00b100;\
-         \n  c178: #00b200;\
-         \n  c179: #00b300;\
-         \n  c180: #00b400;\
-         \n  c181: #00b500;\
-         \n  c182: #00b600;\
-         \n  c183: #00b700;\
-         \n  c184: #00b800;\
-         \n  c185: #00b900;\
-         \n  c186: #00ba00;\
-         \n  c187: #00bb00;\
-         \n  c188: #00bc00;\
-         \n  c189: #00bd00;\
-         \n  c190: #00be00;\
-         \n  c191: #00bf00;\
-         \n  c192: #00c000;\
-         \n  c193: #00c100;\
-         \n  c194: #00c200;\
-         \n  c195: #00c300;\
-         \n  c196: #00c400;\
-         \n  c197: #00c500;\
-         \n  c198: #00c600;\
-         \n  c199: #00c700;\
-         \n  c200: #00c800;\
-         \n  c201: #00c900;\
-         \n  c202: #00ca00;\
-         \n  c203: #00cb00;\
-         \n  c204: #00cc00;\
-         \n  c205: #00cd00;\
-         \n  c206: #00ce00;\
-         \n  c207: #00cf00;\
-         \n  c208: #00d000;\
-         \n  c209: #00d100;\
-         \n  c210: #00d200;\
-         \n  c211: #00d300;\
-         \n  c212: #00d400;\
-         \n  c213: #00d500;\
-         \n  c214: #00d600;\
-         \n  c215: #00d700;\
-         \n  c216: #00d800;\
-         \n  c217: #00d900;\
-         \n  c218: #00da00;\
-         \n  c219: #00db00;\
-         \n  c220: #00dc00;\
-         \n  c221: #00dd00;\
-         \n  c222: #00de00;\
-         \n  c223: #00df00;\
-         \n  c224: #00e000;\
-         \n  c225: #00e100;\
-         \n  c226: #00e200;\
-         \n  c227: #00e300;\
-         \n  c228: #00e400;\
-         \n  c229: #00e500;\
-         \n  c230: #00e600;\
-         \n  c231: #00e700;\
-         \n  c232: #00e800;\
-         \n  c233: #00e900;\
-         \n  c234: #00ea00;\
-         \n  c235: #00eb00;\
-         \n  c236: #00ec00;\
-         \n  c237: #00ed00;\
-         \n  c238: #00ee00;\
-         \n  c239: #00ef00;\
-         \n  c240: #00f000;\
-         \n  c241: #00f100;\
-         \n  c242: #00f200;\
-         \n  c243: #00f300;\
-         \n  c244: #00f400;\
-         \n  c245: #00f500;\
-         \n  c246: #00f600;\
-         \n  c247: #00f700;\
-         \n  c248: #00f800;\
-         \n  c249: #00f900;\
-         \n  c250: #00fa00;\
-         \n  c251: #00fb00;\
-         \n  c252: #00fc00;\
-         \n  c253: #00fd00;\
-         \n  c254: #00fe00;\
-         \n  c255: lime;\
-         \n  c256: lime;\
+         \n  c-1: rgb(0, 0, 0);\
+         \n  c0: rgb(0, 0, 0);\
+         \n  c1: rgb(0, 1, 0);\
+         \n  c2: rgb(0, 2, 0);\
+         \n  c3: rgb(0, 3, 0);\
+         \n  c4: rgb(0, 4, 0);\
+         \n  c5: rgb(0, 5, 0);\
+         \n  c6: rgb(0, 6, 0);\
+         \n  c7: rgb(0, 7, 0);\
+         \n  c8: rgb(0, 8, 0);\
+         \n  c9: rgb(0, 9, 0);\
+         \n  c10: rgb(0, 10, 0);\
+         \n  c11: rgb(0, 11, 0);\
+         \n  c12: rgb(0, 12, 0);\
+         \n  c13: rgb(0, 13, 0);\
+         \n  c14: rgb(0, 14, 0);\
+         \n  c15: rgb(0, 15, 0);\
+         \n  c16: rgb(0, 16, 0);\
+         \n  c17: rgb(0, 17, 0);\
+         \n  c18: rgb(0, 18, 0);\
+         \n  c19: rgb(0, 19, 0);\
+         \n  c20: rgb(0, 20, 0);\
+         \n  c21: rgb(0, 21, 0);\
+         \n  c22: rgb(0, 22, 0);\
+         \n  c23: rgb(0, 23, 0);\
+         \n  c24: rgb(0, 24, 0);\
+         \n  c25: rgb(0, 25, 0);\
+         \n  c26: rgb(0, 26, 0);\
+         \n  c27: rgb(0, 27, 0);\
+         \n  c28: rgb(0, 28, 0);\
+         \n  c29: rgb(0, 29, 0);\
+         \n  c30: rgb(0, 30, 0);\
+         \n  c31: rgb(0, 31, 0);\
+         \n  c32: rgb(0, 32, 0);\
+         \n  c33: rgb(0, 33, 0);\
+         \n  c34: rgb(0, 34, 0);\
+         \n  c35: rgb(0, 35, 0);\
+         \n  c36: rgb(0, 36, 0);\
+         \n  c37: rgb(0, 37, 0);\
+         \n  c38: rgb(0, 38, 0);\
+         \n  c39: rgb(0, 39, 0);\
+         \n  c40: rgb(0, 40, 0);\
+         \n  c41: rgb(0, 41, 0);\
+         \n  c42: rgb(0, 42, 0);\
+         \n  c43: rgb(0, 43, 0);\
+         \n  c44: rgb(0, 44, 0);\
+         \n  c45: rgb(0, 45, 0);\
+         \n  c46: rgb(0, 46, 0);\
+         \n  c47: rgb(0, 47, 0);\
+         \n  c48: rgb(0, 48, 0);\
+         \n  c49: rgb(0, 49, 0);\
+         \n  c50: rgb(0, 50, 0);\
+         \n  c51: rgb(0, 51, 0);\
+         \n  c52: rgb(0, 52, 0);\
+         \n  c53: rgb(0, 53, 0);\
+         \n  c54: rgb(0, 54, 0);\
+         \n  c55: rgb(0, 55, 0);\
+         \n  c56: rgb(0, 56, 0);\
+         \n  c57: rgb(0, 57, 0);\
+         \n  c58: rgb(0, 58, 0);\
+         \n  c59: rgb(0, 59, 0);\
+         \n  c60: rgb(0, 60, 0);\
+         \n  c61: rgb(0, 61, 0);\
+         \n  c62: rgb(0, 62, 0);\
+         \n  c63: rgb(0, 63, 0);\
+         \n  c64: rgb(0, 64, 0);\
+         \n  c65: rgb(0, 65, 0);\
+         \n  c66: rgb(0, 66, 0);\
+         \n  c67: rgb(0, 67, 0);\
+         \n  c68: rgb(0, 68, 0);\
+         \n  c69: rgb(0, 69, 0);\
+         \n  c70: rgb(0, 70, 0);\
+         \n  c71: rgb(0, 71, 0);\
+         \n  c72: rgb(0, 72, 0);\
+         \n  c73: rgb(0, 73, 0);\
+         \n  c74: rgb(0, 74, 0);\
+         \n  c75: rgb(0, 75, 0);\
+         \n  c76: rgb(0, 76, 0);\
+         \n  c77: rgb(0, 77, 0);\
+         \n  c78: rgb(0, 78, 0);\
+         \n  c79: rgb(0, 79, 0);\
+         \n  c80: rgb(0, 80, 0);\
+         \n  c81: rgb(0, 81, 0);\
+         \n  c82: rgb(0, 82, 0);\
+         \n  c83: rgb(0, 83, 0);\
+         \n  c84: rgb(0, 84, 0);\
+         \n  c85: rgb(0, 85, 0);\
+         \n  c86: rgb(0, 86, 0);\
+         \n  c87: rgb(0, 87, 0);\
+         \n  c88: rgb(0, 88, 0);\
+         \n  c89: rgb(0, 89, 0);\
+         \n  c90: rgb(0, 90, 0);\
+         \n  c91: rgb(0, 91, 0);\
+         \n  c92: rgb(0, 92, 0);\
+         \n  c93: rgb(0, 93, 0);\
+         \n  c94: rgb(0, 94, 0);\
+         \n  c95: rgb(0, 95, 0);\
+         \n  c96: rgb(0, 96, 0);\
+         \n  c97: rgb(0, 97, 0);\
+         \n  c98: rgb(0, 98, 0);\
+         \n  c99: rgb(0, 99, 0);\
+         \n  c100: rgb(0, 100, 0);\
+         \n  c101: rgb(0, 101, 0);\
+         \n  c102: rgb(0, 102, 0);\
+         \n  c103: rgb(0, 103, 0);\
+         \n  c104: rgb(0, 104, 0);\
+         \n  c105: rgb(0, 105, 0);\
+         \n  c106: rgb(0, 106, 0);\
+         \n  c107: rgb(0, 107, 0);\
+         \n  c108: rgb(0, 108, 0);\
+         \n  c109: rgb(0, 109, 0);\
+         \n  c110: rgb(0, 110, 0);\
+         \n  c111: rgb(0, 111, 0);\
+         \n  c112: rgb(0, 112, 0);\
+         \n  c113: rgb(0, 113, 0);\
+         \n  c114: rgb(0, 114, 0);\
+         \n  c115: rgb(0, 115, 0);\
+         \n  c116: rgb(0, 116, 0);\
+         \n  c117: rgb(0, 117, 0);\
+         \n  c118: rgb(0, 118, 0);\
+         \n  c119: rgb(0, 119, 0);\
+         \n  c120: rgb(0, 120, 0);\
+         \n  c121: rgb(0, 121, 0);\
+         \n  c122: rgb(0, 122, 0);\
+         \n  c123: rgb(0, 123, 0);\
+         \n  c124: rgb(0, 124, 0);\
+         \n  c125: rgb(0, 125, 0);\
+         \n  c126: rgb(0, 126, 0);\
+         \n  c127: rgb(0, 127, 0);\
+         \n  c128: rgb(0, 128, 0);\
+         \n  c129: rgb(0, 129, 0);\
+         \n  c130: rgb(0, 130, 0);\
+         \n  c131: rgb(0, 131, 0);\
+         \n  c132: rgb(0, 132, 0);\
+         \n  c133: rgb(0, 133, 0);\
+         \n  c134: rgb(0, 134, 0);\
+         \n  c135: rgb(0, 135, 0);\
+         \n  c136: rgb(0, 136, 0);\
+         \n  c137: rgb(0, 137, 0);\
+         \n  c138: rgb(0, 138, 0);\
+         \n  c139: rgb(0, 139, 0);\
+         \n  c140: rgb(0, 140, 0);\
+         \n  c141: rgb(0, 141, 0);\
+         \n  c142: rgb(0, 142, 0);\
+         \n  c143: rgb(0, 143, 0);\
+         \n  c144: rgb(0, 144, 0);\
+         \n  c145: rgb(0, 145, 0);\
+         \n  c146: rgb(0, 146, 0);\
+         \n  c147: rgb(0, 147, 0);\
+         \n  c148: rgb(0, 148, 0);\
+         \n  c149: rgb(0, 149, 0);\
+         \n  c150: rgb(0, 150, 0);\
+         \n  c151: rgb(0, 151, 0);\
+         \n  c152: rgb(0, 152, 0);\
+         \n  c153: rgb(0, 153, 0);\
+         \n  c154: rgb(0, 154, 0);\
+         \n  c155: rgb(0, 155, 0);\
+         \n  c156: rgb(0, 156, 0);\
+         \n  c157: rgb(0, 157, 0);\
+         \n  c158: rgb(0, 158, 0);\
+         \n  c159: rgb(0, 159, 0);\
+         \n  c160: rgb(0, 160, 0);\
+         \n  c161: rgb(0, 161, 0);\
+         \n  c162: rgb(0, 162, 0);\
+         \n  c163: rgb(0, 163, 0);\
+         \n  c164: rgb(0, 164, 0);\
+         \n  c165: rgb(0, 165, 0);\
+         \n  c166: rgb(0, 166, 0);\
+         \n  c167: rgb(0, 167, 0);\
+         \n  c168: rgb(0, 168, 0);\
+         \n  c169: rgb(0, 169, 0);\
+         \n  c170: rgb(0, 170, 0);\
+         \n  c171: rgb(0, 171, 0);\
+         \n  c172: rgb(0, 172, 0);\
+         \n  c173: rgb(0, 173, 0);\
+         \n  c174: rgb(0, 174, 0);\
+         \n  c175: rgb(0, 175, 0);\
+         \n  c176: rgb(0, 176, 0);\
+         \n  c177: rgb(0, 177, 0);\
+         \n  c178: rgb(0, 178, 0);\
+         \n  c179: rgb(0, 179, 0);\
+         \n  c180: rgb(0, 180, 0);\
+         \n  c181: rgb(0, 181, 0);\
+         \n  c182: rgb(0, 182, 0);\
+         \n  c183: rgb(0, 183, 0);\
+         \n  c184: rgb(0, 184, 0);\
+         \n  c185: rgb(0, 185, 0);\
+         \n  c186: rgb(0, 186, 0);\
+         \n  c187: rgb(0, 187, 0);\
+         \n  c188: rgb(0, 188, 0);\
+         \n  c189: rgb(0, 189, 0);\
+         \n  c190: rgb(0, 190, 0);\
+         \n  c191: rgb(0, 191, 0);\
+         \n  c192: rgb(0, 192, 0);\
+         \n  c193: rgb(0, 193, 0);\
+         \n  c194: rgb(0, 194, 0);\
+         \n  c195: rgb(0, 195, 0);\
+         \n  c196: rgb(0, 196, 0);\
+         \n  c197: rgb(0, 197, 0);\
+         \n  c198: rgb(0, 198, 0);\
+         \n  c199: rgb(0, 199, 0);\
+         \n  c200: rgb(0, 200, 0);\
+         \n  c201: rgb(0, 201, 0);\
+         \n  c202: rgb(0, 202, 0);\
+         \n  c203: rgb(0, 203, 0);\
+         \n  c204: rgb(0, 204, 0);\
+         \n  c205: rgb(0, 205, 0);\
+         \n  c206: rgb(0, 206, 0);\
+         \n  c207: rgb(0, 207, 0);\
+         \n  c208: rgb(0, 208, 0);\
+         \n  c209: rgb(0, 209, 0);\
+         \n  c210: rgb(0, 210, 0);\
+         \n  c211: rgb(0, 211, 0);\
+         \n  c212: rgb(0, 212, 0);\
+         \n  c213: rgb(0, 213, 0);\
+         \n  c214: rgb(0, 214, 0);\
+         \n  c215: rgb(0, 215, 0);\
+         \n  c216: rgb(0, 216, 0);\
+         \n  c217: rgb(0, 217, 0);\
+         \n  c218: rgb(0, 218, 0);\
+         \n  c219: rgb(0, 219, 0);\
+         \n  c220: rgb(0, 220, 0);\
+         \n  c221: rgb(0, 221, 0);\
+         \n  c222: rgb(0, 222, 0);\
+         \n  c223: rgb(0, 223, 0);\
+         \n  c224: rgb(0, 224, 0);\
+         \n  c225: rgb(0, 225, 0);\
+         \n  c226: rgb(0, 226, 0);\
+         \n  c227: rgb(0, 227, 0);\
+         \n  c228: rgb(0, 228, 0);\
+         \n  c229: rgb(0, 229, 0);\
+         \n  c230: rgb(0, 230, 0);\
+         \n  c231: rgb(0, 231, 0);\
+         \n  c232: rgb(0, 232, 0);\
+         \n  c233: rgb(0, 233, 0);\
+         \n  c234: rgb(0, 234, 0);\
+         \n  c235: rgb(0, 235, 0);\
+         \n  c236: rgb(0, 236, 0);\
+         \n  c237: rgb(0, 237, 0);\
+         \n  c238: rgb(0, 238, 0);\
+         \n  c239: rgb(0, 239, 0);\
+         \n  c240: rgb(0, 240, 0);\
+         \n  c241: rgb(0, 241, 0);\
+         \n  c242: rgb(0, 242, 0);\
+         \n  c243: rgb(0, 243, 0);\
+         \n  c244: rgb(0, 244, 0);\
+         \n  c245: rgb(0, 245, 0);\
+         \n  c246: rgb(0, 246, 0);\
+         \n  c247: rgb(0, 247, 0);\
+         \n  c248: rgb(0, 248, 0);\
+         \n  c249: rgb(0, 249, 0);\
+         \n  c250: rgb(0, 250, 0);\
+         \n  c251: rgb(0, 251, 0);\
+         \n  c252: rgb(0, 252, 0);\
+         \n  c253: rgb(0, 253, 0);\
+         \n  c254: rgb(0, 254, 0);\
+         \n  c255: rgb(0, 255, 0);\
+         \n  c256: rgb(0, 255, 0);\
          \n}\
          \nfoo {\
-         \n  c-1: black;\
-         \n  c0: black;\
-         \n  c1: #030000;\
-         \n  c2: #050000;\
-         \n  c3: #080000;\
-         \n  c4: #0a0000;\
-         \n  c5: #0d0000;\
-         \n  c6: #0f0000;\
-         \n  c7: #120000;\
-         \n  c8: #140000;\
-         \n  c9: #170000;\
-         \n  c10: #1a0000;\
-         \n  c11: #1c0000;\
-         \n  c12: #1f0000;\
-         \n  c13: #210000;\
-         \n  c14: #240000;\
-         \n  c15: #260000;\
-         \n  c16: #290000;\
-         \n  c17: #2b0000;\
-         \n  c18: #2e0000;\
-         \n  c19: #300000;\
-         \n  c20: #330000;\
-         \n  c21: #360000;\
-         \n  c22: #380000;\
-         \n  c23: #3b0000;\
-         \n  c24: #3d0000;\
-         \n  c25: #400000;\
-         \n  c26: #420000;\
-         \n  c27: #450000;\
-         \n  c28: #470000;\
-         \n  c29: #4a0000;\
-         \n  c30: #4d0000;\
-         \n  c31: #4f0000;\
-         \n  c32: #520000;\
-         \n  c33: #540000;\
-         \n  c34: #570000;\
-         \n  c35: #590000;\
-         \n  c36: #5c0000;\
-         \n  c37: #5e0000;\
-         \n  c38: #610000;\
-         \n  c39: #630000;\
-         \n  c40: #660000;\
-         \n  c41: #690000;\
-         \n  c42: #6b0000;\
-         \n  c43: #6e0000;\
-         \n  c44: #700000;\
-         \n  c45: #730000;\
-         \n  c46: #750000;\
-         \n  c47: #780000;\
-         \n  c48: #7a0000;\
-         \n  c49: #7d0000;\
-         \n  c50: maroon;\
-         \n  c51: #820000;\
-         \n  c52: #850000;\
-         \n  c53: #870000;\
-         \n  c54: #8a0000;\
-         \n  c55: #8c0000;\
-         \n  c56: #8f0000;\
-         \n  c57: #910000;\
-         \n  c58: #940000;\
-         \n  c59: #960000;\
-         \n  c60: #990000;\
-         \n  c61: #9c0000;\
-         \n  c62: #9e0000;\
-         \n  c63: #a10000;\
-         \n  c64: #a30000;\
-         \n  c65: #a60000;\
-         \n  c66: #a80000;\
-         \n  c67: #ab0000;\
-         \n  c68: #ad0000;\
-         \n  c69: #b00000;\
-         \n  c70: #b30000;\
-         \n  c71: #b50000;\
-         \n  c72: #b80000;\
-         \n  c73: #ba0000;\
-         \n  c74: #bd0000;\
-         \n  c75: #bf0000;\
-         \n  c76: #c20000;\
-         \n  c77: #c40000;\
-         \n  c78: #c70000;\
-         \n  c79: #c90000;\
-         \n  c80: #cc0000;\
-         \n  c81: #cf0000;\
-         \n  c82: #d10000;\
-         \n  c83: #d40000;\
-         \n  c84: #d60000;\
-         \n  c85: #d90000;\
-         \n  c86: #db0000;\
-         \n  c87: #de0000;\
-         \n  c88: #e00000;\
-         \n  c89: #e30000;\
-         \n  c90: #e60000;\
-         \n  c91: #e80000;\
-         \n  c92: #eb0000;\
-         \n  c93: #ed0000;\
-         \n  c94: #f00000;\
-         \n  c95: #f20000;\
-         \n  c96: #f50000;\
-         \n  c97: #f70000;\
-         \n  c98: #fa0000;\
-         \n  c99: #fc0000;\
-         \n  c100: red;\
-         \n  c101: red;\
+         \n  c-1: rgb(0, 0, 0);\
+         \n  c0: rgb(0, 0, 0);\
+         \n  c1: rgb(3, 0, 0);\
+         \n  c2: rgb(5, 0, 0);\
+         \n  c3: rgb(8, 0, 0);\
+         \n  c4: rgb(10, 0, 0);\
+         \n  c5: rgb(13, 0, 0);\
+         \n  c6: rgb(15, 0, 0);\
+         \n  c7: rgb(18, 0, 0);\
+         \n  c8: rgb(20, 0, 0);\
+         \n  c9: rgb(23, 0, 0);\
+         \n  c10: rgb(26, 0, 0);\
+         \n  c11: rgb(28, 0, 0);\
+         \n  c12: rgb(31, 0, 0);\
+         \n  c13: rgb(33, 0, 0);\
+         \n  c14: rgb(36, 0, 0);\
+         \n  c15: rgb(38, 0, 0);\
+         \n  c16: rgb(41, 0, 0);\
+         \n  c17: rgb(43, 0, 0);\
+         \n  c18: rgb(46, 0, 0);\
+         \n  c19: rgb(48, 0, 0);\
+         \n  c20: rgb(51, 0, 0);\
+         \n  c21: rgb(54, 0, 0);\
+         \n  c22: rgb(56, 0, 0);\
+         \n  c23: rgb(59, 0, 0);\
+         \n  c24: rgb(61, 0, 0);\
+         \n  c25: rgb(64, 0, 0);\
+         \n  c26: rgb(66, 0, 0);\
+         \n  c27: rgb(69, 0, 0);\
+         \n  c28: rgb(71, 0, 0);\
+         \n  c29: rgb(74, 0, 0);\
+         \n  c30: rgb(77, 0, 0);\
+         \n  c31: rgb(79, 0, 0);\
+         \n  c32: rgb(82, 0, 0);\
+         \n  c33: rgb(84, 0, 0);\
+         \n  c34: rgb(87, 0, 0);\
+         \n  c35: rgb(89, 0, 0);\
+         \n  c36: rgb(92, 0, 0);\
+         \n  c37: rgb(94, 0, 0);\
+         \n  c38: rgb(97, 0, 0);\
+         \n  c39: rgb(99, 0, 0);\
+         \n  c40: rgb(102, 0, 0);\
+         \n  c41: rgb(105, 0, 0);\
+         \n  c42: rgb(107, 0, 0);\
+         \n  c43: rgb(110, 0, 0);\
+         \n  c44: rgb(112, 0, 0);\
+         \n  c45: rgb(115, 0, 0);\
+         \n  c46: rgb(117, 0, 0);\
+         \n  c47: rgb(120, 0, 0);\
+         \n  c48: rgb(122, 0, 0);\
+         \n  c49: rgb(125, 0, 0);\
+         \n  c50: rgb(128, 0, 0);\
+         \n  c51: rgb(130, 0, 0);\
+         \n  c52: rgb(133, 0, 0);\
+         \n  c53: rgb(135, 0, 0);\
+         \n  c54: rgb(138, 0, 0);\
+         \n  c55: rgb(140, 0, 0);\
+         \n  c56: rgb(143, 0, 0);\
+         \n  c57: rgb(145, 0, 0);\
+         \n  c58: rgb(148, 0, 0);\
+         \n  c59: rgb(150, 0, 0);\
+         \n  c60: rgb(153, 0, 0);\
+         \n  c61: rgb(156, 0, 0);\
+         \n  c62: rgb(158, 0, 0);\
+         \n  c63: rgb(161, 0, 0);\
+         \n  c64: rgb(163, 0, 0);\
+         \n  c65: rgb(166, 0, 0);\
+         \n  c66: rgb(168, 0, 0);\
+         \n  c67: rgb(171, 0, 0);\
+         \n  c68: rgb(173, 0, 0);\
+         \n  c69: rgb(176, 0, 0);\
+         \n  c70: rgb(179, 0, 0);\
+         \n  c71: rgb(181, 0, 0);\
+         \n  c72: rgb(184, 0, 0);\
+         \n  c73: rgb(186, 0, 0);\
+         \n  c74: rgb(189, 0, 0);\
+         \n  c75: rgb(191, 0, 0);\
+         \n  c76: rgb(194, 0, 0);\
+         \n  c77: rgb(196, 0, 0);\
+         \n  c78: rgb(199, 0, 0);\
+         \n  c79: rgb(201, 0, 0);\
+         \n  c80: rgb(204, 0, 0);\
+         \n  c81: rgb(207, 0, 0);\
+         \n  c82: rgb(209, 0, 0);\
+         \n  c83: rgb(212, 0, 0);\
+         \n  c84: rgb(214, 0, 0);\
+         \n  c85: rgb(217, 0, 0);\
+         \n  c86: rgb(219, 0, 0);\
+         \n  c87: rgb(222, 0, 0);\
+         \n  c88: rgb(224, 0, 0);\
+         \n  c89: rgb(227, 0, 0);\
+         \n  c90: rgb(230, 0, 0);\
+         \n  c91: rgb(232, 0, 0);\
+         \n  c92: rgb(235, 0, 0);\
+         \n  c93: rgb(237, 0, 0);\
+         \n  c94: rgb(240, 0, 0);\
+         \n  c95: rgb(242, 0, 0);\
+         \n  c96: rgb(245, 0, 0);\
+         \n  c97: rgb(247, 0, 0);\
+         \n  c98: rgb(250, 0, 0);\
+         \n  c99: rgb(252, 0, 0);\
+         \n  c100: rgb(255, 0, 0);\
+         \n  c101: rgb(255, 0, 0);\
          \n}\n"
     );
 }
