@@ -17,12 +17,12 @@ fn test() {
              \n  foo: rgb(200, 150%, 170%);\
              \n}"),
         "p {\
-         \n  color: #ff8000;\
+         \n  color: rgb(255, 128, 0);\
          \n  color: red green blue;\
          \n  color: red green blue;\
          \n  color: redhux;\
          \n  color: redgreen;\
-         \n  foo: #c8ffff;\
+         \n  foo: rgb(200, 255, 255);\
          \n}\n"
     );
 }
